@@ -1,3 +1,5 @@
+import re
+
 import requests
 import json
 import requests.auth
@@ -7,24 +9,22 @@ from random import SystemRandom
 import datetime
 
 from .reddit import Reddit
-from .exceptions import RequestError
+from .exceptions import RequestError, EmptyResult
 from .client import Client
 
 cryptogen = SystemRandom()
 
 
-async def async_request(async_headers, async_client_auth, rtype, rfor, slash):
+async def async_request(headers, client_auth, rtype, rfor, slash):
     async with aiohttp.ClientSession() as cs:
-        async with cs.get(f"https://reddit.com/{slash}/{rfor}/{rtype}.json", headers=async_headers,
-                          auth=async_client_auth) as r:
+        async with cs.get(f"https://reddit.com/{slash}/{rfor}/{rtype}.json", headers=headers,
+                          auth=client_auth) as r:
             content = await r.json()
             return content
 
 
-def get_request(client_id, client_secret, headers, rtype, slash, rfor):
-    client_auth = requests.auth.HTTPBasicAuth(client_id, client_secret)
-    request = requests.get(f"https://www.reddit.com/{slash}/{rfor}/{rtype}.json", headers=headers,
-                           auth=client_auth)
+def get_request(client_auth, headers, rtype, slash, rfor):
+    request = requests.get(f"https://www.reddit.com/{slash}/{rfor}/{rtype}.json", headers=headers, auth=client_auth)
     return json.loads(request.content)
 
 
@@ -37,16 +37,16 @@ def check_for_api_error(response: dict):
 def get_post(self, rtype, slash, rfor):
     if self.client_id is None or self.client_secret is None or self.user_agent is None:
         headers = {"User-Agent": Client.USER_AGENT.name}
-        meme = get_request(Client.CLIENT_ID.name, Client.CLIENT_SECRET.name, headers, rtype=rtype, rfor=rfor,
-                           slash=slash)
+        client_auth = requests.auth.HTTPBasicAuth(Client.CLIENT_ID.name, Client.CLIENT_SECRET.name)
 
     else:
         headers = {"User-Agent": self.user_agent}
-        meme = get_request(self.client_id, self.client_secret, headers, rtype=rtype, rfor=rfor,
-                           slash=slash)
+        client_auth = requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+
+    meme = get_request(client_auth, headers, rtype=rtype, rfor=rfor, slash=slash)
+    check_for_api_error(meme)
 
     try:
-        check_for_api_error(meme)
         post = meme["data"]["children"]
 
         try:
@@ -59,6 +59,8 @@ def get_post(self, rtype, slash, rfor):
             if post[randompost]["data"]["stickied"]:
                 randompost += 1
             nsfw = post[randompost]["data"]["over_18"]
+        except ValueError:
+            raise EmptyResult("The given user / subreddit is empty")
 
         stickied = post[randompost]["data"]["stickied"]
         spoiler = post[randompost]["data"]["spoiler"]
@@ -91,6 +93,24 @@ def get_post(self, rtype, slash, rfor):
         else:
             contenttext = post[randompost]["data"]["url_overridden_by_dest"]
 
+        is_media = True if not post[randompost]["data"]["domain"].startswith("self") else False
+
+        regex_url = re.compile(r'^(?:http|ftp)s?://')
+
+        regex_url_image = re.compile(
+            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:jpg|gif|png))(?:\?([^#]*))?(?:#(.*))?')
+        regex_url_video = re.compile(
+            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:mov|mp4))(?:\?([^#]*))?(?:#(.*))?')
+
+        if re.match(regex_url_image, contenttext):
+            content_type = "Image"
+        elif re.match(regex_url_video, contenttext):
+            content_type = "Video"
+        elif re.match(regex_url, contenttext):
+            content_type = "URL"
+        else:
+            content_type = "Text"
+
         return Reddit(
             content=contenttext,
             title=post[randompost]["data"]["title"],
@@ -108,10 +128,12 @@ def get_post(self, rtype, slash, rfor):
             author_flair=flair_author,
             post_flair=flair_post,
             subreddit_subscribers=post[randompost]["data"]["subreddit_subscribers"],
-            comment_count=post[randompost]["data"]["num_comments"]
+            comment_count=post[randompost]["data"]["num_comments"],
+            is_media=is_media,
+            subreddit_name=post[randompost]["data"]["subreddit"],
+            content_type=content_type
         )
     except KeyError:
-        check_for_api_error(meme)
         post = meme["data"]["children"]
 
         try:
@@ -158,6 +180,24 @@ def get_post(self, rtype, slash, rfor):
         else:
             contenttext = post[randompost]["data"]["url"]
 
+        is_media = True if not post[randompost]["data"]["domain"].startswith("self") else False
+
+        regex_url = re.compile(r'^(?:http|ftp)s?://')
+
+        regex_url_image = re.compile(
+            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:jpg|gif|png))(?:\?([^#]*))?(?:#(.*))?')
+        regex_url_video = re.compile(
+            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:mov|mp4))(?:\?([^#]*))?(?:#(.*))?')
+
+        if re.match(regex_url_image, contenttext):
+            content_type = "Image"
+        elif re.match(regex_url_video, contenttext):
+            content_type = "Video"
+        elif re.match(regex_url, contenttext):
+            content_type = "URL"
+        else:
+            content_type = "Text"
+
 
         return Reddit(
             content=contenttext,
@@ -176,7 +216,10 @@ def get_post(self, rtype, slash, rfor):
             author_flair=flair_author,
             post_flair=flair_post,
             subreddit_subscribers=post[randompost]["data"]["subreddit_subscribers"],
-            comment_count=post[randompost]["data"]["num_comments"]
+            comment_count=post[randompost]["data"]["num_comments"],
+            is_media=is_media,
+            subreddit_name=post[randompost]["data"]["subreddit"],
+            content_type=content_type
         )
 
 
@@ -185,18 +228,14 @@ async def get_async_post(self, rtype, rfor, slash):
         client_auth = aiohttp.BasicAuth(Client.CLIENT_ID.name, Client.CLIENT_SECRET.name)
         headers = {"User-Agent": Client.USER_AGENT.name}
 
-        meme = await async_request(async_headers=headers, async_client_auth=client_auth, rtype=rtype, rfor=rfor,
-                                   slash=slash)
-
     else:
         client_auth = aiohttp.BasicAuth(self.client_id, self.client_secret)
         headers = {"User-Agent": self.user_agent}
 
-        meme = await async_request(async_headers=headers, async_client_auth=client_auth, rtype=rtype, rfor=rfor,
-                                   slash=slash)
+    meme = await async_request(headers=headers, client_auth=client_auth, rtype=rtype, rfor=rfor, slash=slash)
+    check_for_api_error(meme)
 
     try:
-        check_for_api_error(meme)
         post = meme["data"]["children"]
 
         try:
@@ -241,6 +280,25 @@ async def get_async_post(self, rtype, rfor, slash):
         else:
             contenttext = post[randompost]["data"]["url_overridden_by_dest"]
 
+        is_media = True if not post[randompost]["data"]["domain"].startswith("self") else False
+
+        regex_url = re.compile(r'^(?:http|ftp)s?://')
+
+        regex_url_image = re.compile(
+            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:jpg|gif|png))(?:\?([^#]*))?(?:#(.*))?')
+        regex_url_video = re.compile(
+            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:mov|mp4))(?:\?([^#]*))?(?:#(.*))?')
+
+        if re.match(regex_url_image, contenttext):
+            content_type = "Image"
+        elif re.match(regex_url_video, contenttext):
+            content_type = "Video"
+        elif re.match(regex_url, contenttext):
+            content_type = "URL"
+        else:
+            content_type = "Text"
+
+
         return Reddit(
             content=contenttext,
             title=post[randompost]["data"]["title"],
@@ -258,10 +316,12 @@ async def get_async_post(self, rtype, rfor, slash):
             author_flair=flair_author,
             post_flair=flair_post,
             subreddit_subscribers=post[randompost]["data"]["subreddit_subscribers"],
-            comment_count=post[randompost]["data"]["num_comments"]
+            comment_count=post[randompost]["data"]["num_comments"],
+            is_media=is_media,
+            subreddit_name=post[randompost]["data"]["subreddit"],
+            content_type=content_type
         )
     except KeyError:
-        check_for_api_error(meme)
         post = meme["data"]["children"]
 
         try:
@@ -308,6 +368,24 @@ async def get_async_post(self, rtype, rfor, slash):
         else:
             contenttext = post[randompost]["data"]["url"]
 
+        is_media = True if not post[randompost]["data"]["domain"].startswith("self") else False
+
+        regex_url = re.compile(r'^(?:http|ftp)s?://')
+
+        regex_url_image = re.compile(
+            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:jpg|gif|png))(?:\?([^#]*))?(?:#(.*))?')
+        regex_url_video = re.compile(
+            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:mov|mp4))(?:\?([^#]*))?(?:#(.*))?')
+
+        if re.match(regex_url_image, contenttext):
+            content_type = "Image"
+        elif re.match(regex_url_video, contenttext):
+            content_type = "Video"
+        elif re.match(regex_url, contenttext):
+            content_type = "URL"
+        else:
+            content_type = "Text"
+
         return Reddit(
             content=contenttext,
             title=post[randompost]["data"]["title"],
@@ -325,7 +403,10 @@ async def get_async_post(self, rtype, rfor, slash):
             author_flair=flair_author,
             post_flair=flair_post,
             subreddit_subscribers=post[randompost]["data"]["subreddit_subscribers"],
-            comment_count=post[randompost]["data"]["num_comments"]
+            comment_count=post[randompost]["data"]["num_comments"],
+            is_media=is_media,
+            subreddit_name=post[randompost]["data"]["subreddit"],
+            content_type=content_type
         )
 
 
